from bot_core.logging.database_logger import DatabaseLogger
from bot_data.abc.migration_abc import MigrationABC
from bot_data.db_context import DBContext


class ShortRoleNameOnlyHighestMigration(MigrationABC):
    name = "1.1.9_ShortRoleNameOnlyHighestMigration"

    def __init__(self, logger: DatabaseLogger, db: DBContext):
        MigrationABC.__init__(self)
        self._logger = logger
        self._db = db
        self._cursor = db.cursor

    def upgrade(self):
        self._logger.debug(__name__, "Running upgrade")

        self._cursor.execute(
            str(
                f"""
                    ALTER TABLE CFG_Server
                    ADD ShortRoleNameSetOnlyHighest BOOLEAN NOT NULL DEFAULT FALSE AFTER DefaultRoleId;
                """
            )
        )

        self._cursor.execute(
            str(
                f"""
                    ALTER TABLE CFG_ServerHistory
                    ADD ShortRoleNameSetOnlyHighest BOOLEAN NOT NULL DEFAULT FALSE AFTER DefaultRoleId;
                """
            )
        )
        self._exec(__file__, "config/server.sql")

    def downgrade(self):
        self._cursor.execute(
            str(
                f"""
                    ALTER TABLE CFG_Server DROP COLUMN ShortRoleNameSetOnlyHighest;
                """
            )
        )
        self._cursor.execute(
            str(
                f"""
                    ALTER TABLE CFG_ServerHistory DROP COLUMN ShortRoleNameSetOnlyHighest;
                """
            )
        )
