from typing import List

import discord
from cpl_core.configuration import ConfigurationABC
from cpl_discord.command import DiscordCommandABC
from cpl_discord.service import DiscordBotServiceABC
from discord import app_commands
from discord.ext import commands
from discord.ext.commands import Context

from bot_core.abc.client_utils_abc import ClientUtilsABC
from bot_core.abc.message_service_abc import MessageServiceABC
from bot_core.helper.command_checks import CommandChecks
from bot_core.logging.command_logger import CommandLogger
from bot_data.model.technician_config import TechnicianConfig


class HelpCommand(DiscordCommandABC):
    def __init__(
        self,
        config: ConfigurationABC,
        logger: CommandLogger,
        message_service: MessageServiceABC,
        bot: DiscordBotServiceABC,
        client_utils: ClientUtilsABC,
    ):
        DiscordCommandABC.__init__(self)

        self._config = config
        self._logger = logger
        self._message_service = message_service
        self._bot = bot
        self._client_utils = client_utils

        self._logger.trace(__name__, f"Loaded command service: {type(self).__name__}")

    @commands.hybrid_command()
    @commands.guild_only()
    @CommandChecks.check_is_ready()
    async def help(self, ctx: Context, persistent_flag: str = None):
        self._logger.debug(__name__, f"Received command help {ctx}:{persistent_flag}")
        settings: TechnicianConfig = self._config.get_configuration(TechnicianConfig)
        is_persistent = persistent_flag == "--stay"
        await self._message_service.send_ctx_msg(
            ctx,
            settings.help_command_reference_url,
            is_persistent=is_persistent,
            is_public=True,
        )
        self._logger.trace(__name__, f"Finished help command")

    @help.autocomplete("persistent_flag")
    async def help_autocomplete(self, interaction: discord.Interaction, current: str) -> List[app_commands.Choice[str]]:
        flags = ["--stay"]
        return [app_commands.Choice(name=key, value=key) for key in flags]
