import { Component, OnInit } from "@angular/core";
import { catchError } from "rxjs/operators";
import { SoftwareVersion } from "src/app/models/config/software-version";
import { GuiService } from "src/app/services/gui/gui.service";
import { SettingsService } from "src/app/services/settings/settings.service";
import { SpinnerService } from "src/app/services/spinner/spinner.service";
import { throwError } from "rxjs";

@Component({
  selector: 'app-footer',
  templateUrl: './footer.component.html',
  styleUrls: ['./footer.component.scss']
})
export class FooterComponent implements OnInit {


  public frontendVersion: SoftwareVersion = new SoftwareVersion("0", "0", "0");
  public backendVersion: SoftwareVersion = new SoftwareVersion("0", "0", "0");

  public privacy: string = "";
  public imprint: string  = "";

  constructor(
    private settings: SettingsService,
    private guiService: GuiService,
    private spinnerService: SpinnerService
  ) {}

  ngOnInit(): void {
    this.frontendVersion = this.settings.getWebVersion() ?? new SoftwareVersion('0', '0', '0');

    this.spinnerService.showSpinner();
    this.guiService.getApiVersion()
      .pipe(catchError(error => {
        this.spinnerService.hideSpinner();
        return throwError(() => error);
      }))
      .subscribe(version => {
        this.spinnerService.hideSpinner();
        this.backendVersion = new SoftwareVersion(
          version.major,
          version.minor,
          version.micro
        );
      });
  }

  public navigateToPrivacy(): void {
    window.open(this.settings.getPrivacyURL(), "_blank");
  }

  public navigateToImprint(): void {
    window.open(this.settings.getImprintURL(), "_blank");
  }

}
