import { HttpErrorResponse } from "@angular/common/http";
import { ErrorHandler, Injectable } from "@angular/core";
import { Observable, throwError } from "rxjs";
import { ErrorDTO } from "src/app/models/error/error-dto";
import { ServiceErrorCode } from "src/app/models/error/service-error-code.enum";
import { AuthService } from "../auth/auth.service";
import { ToastService } from "../toast/toast.service";

@Injectable()
export class ErrorHandlerService implements ErrorHandler {

  constructor(
    private auth: AuthService,
    private toast: ToastService,
  ) { }

  handleError(error: HttpErrorResponse): Observable<never> {
    if (error && error.error) {
      let message = 'Unbekannter Fehler';
      let header = 'Fehler';
      const errorDto: ErrorDTO = error.error;

      if (errorDto.errorCode === ServiceErrorCode.Unauthorized) {
        this.auth.logout();
        return throwError(() => error);
      }

      if (errorDto.errorCode !== undefined) {
        header = 'Fehlercode: ' + errorDto.errorCode;
      }

      if (errorDto.message) {
        message = errorDto.message;
      } else if (error.message) {
        message = error.message;
      }

      this.toast.error(header, message);
    } else {
      console.error(error.message);
    }

    if (error.status === 401) {
      this.auth.logout();
    }
    return throwError(() => error);
  }
}
